aboutsummaryrefslogtreecommitdiff
path: root/pythonmod
diff options
context:
space:
mode:
authorDag-Erling Smørgrav <des@FreeBSD.org>2018-05-12 11:55:57 +0000
committerDag-Erling Smørgrav <des@FreeBSD.org>2018-05-12 11:55:57 +0000
commit2bda7bda432fb0f867072224dd97e10435c8ad94 (patch)
tree7ebfd82c2302bee4f9c05fb516c030153fb371d8 /pythonmod
parenta6c5280ea59f940be13fd6eb0f94ab8360d3d6c9 (diff)
downloadsrc-2bda7bda432fb0f867072224dd97e10435c8ad94.tar.gz
src-2bda7bda432fb0f867072224dd97e10435c8ad94.zip
Vendor import of Unbound 1.6.7.vendor/unbound/1.6.7
Notes
Notes: svn path=/vendor/unbound/dist/; revision=333543 svn path=/vendor/unbound/1.6.7/; revision=333544; tag=vendor/unbound/1.6.7
Diffstat (limited to 'pythonmod')
-rw-r--r--pythonmod/doc/examples/example2.rst2
-rw-r--r--pythonmod/doc/examples/example3.rst2
-rw-r--r--pythonmod/doc/examples/example5.rst4
-rw-r--r--pythonmod/doc/examples/example6.rst4
-rw-r--r--pythonmod/doc/modules/functions.rst2
-rw-r--r--pythonmod/doc/modules/struct.rst2
-rw-r--r--pythonmod/doc/usecase.rst2
-rw-r--r--pythonmod/examples/edns.py4
-rw-r--r--pythonmod/examples/inplace_callbacks.py12
-rw-r--r--pythonmod/interface.i2
10 files changed, 18 insertions, 18 deletions
diff --git a/pythonmod/doc/examples/example2.rst b/pythonmod/doc/examples/example2.rst
index 4ba9239a003f..663d1eb777cd 100644
--- a/pythonmod/doc/examples/example2.rst
+++ b/pythonmod/doc/examples/example2.rst
@@ -46,4 +46,4 @@ Dig produces the following output::
;; MSG SIZE rcvd: 54
As we handle (override) in the python module only queries ending with
-``localdomain.``, unboud can still resolve host names.
+``localdomain.``, unbound can still resolve host names.
diff --git a/pythonmod/doc/examples/example3.rst b/pythonmod/doc/examples/example3.rst
index 6213dc188f12..bc0e05f2e32e 100644
--- a/pythonmod/doc/examples/example3.rst
+++ b/pythonmod/doc/examples/example3.rst
@@ -10,7 +10,7 @@ As soon as the iterator module returns the response, we :
3. rewrite the data in cache
4. return modified packet
-Note that the steps 1 and 3 are neccessary only in case, the python module is the first module in the processing chain.
+Note that the steps 1 and 3 are necessary only in case, the python module is the first module in the processing chain.
In other cases, the validator module guarantees updating data which are produced by iterator module.
Complete source code
diff --git a/pythonmod/doc/examples/example5.rst b/pythonmod/doc/examples/example5.rst
index 058fc331e4ba..938d8941bc9c 100644
--- a/pythonmod/doc/examples/example5.rst
+++ b/pythonmod/doc/examples/example5.rst
@@ -3,7 +3,7 @@ EDNS options
This example shows how to interact with EDNS options.
-When quering unbound with the EDNS option ``65001`` and data ``0xc001`` we
+When querying unbound with the EDNS option ``65001`` and data ``0xc001`` we
expect an answer with the same EDNS option code and data ``0xdeadbeef``.
@@ -146,7 +146,7 @@ and use a valid script path::
python-script: "./examples/edns.py"
-Quering with EDNS option ``65001:0xc001``:
+Querying with EDNS option ``65001:0xc001``:
::
diff --git a/pythonmod/doc/examples/example6.rst b/pythonmod/doc/examples/example6.rst
index 07117cd556e7..eb3254022946 100644
--- a/pythonmod/doc/examples/example6.rst
+++ b/pythonmod/doc/examples/example6.rst
@@ -84,7 +84,7 @@ The callback function's prototype is the following:
:param rep: reply_info struct;
:param rcode: return code for the query;
:param edns: edns_data sent from the client side. The list with the EDNS
- options is accesible through edns.opt_list. It SHOULD NOT be
+ options is accessible through edns.opt_list. It SHOULD NOT be
altered;
:param opt_list_out: the list with the EDNS options that will be sent as a
reply. It can be populated with EDNS options;
@@ -120,7 +120,7 @@ The callback function's prototype is the following:
:param rep: reply_info struct;
:param rcode: return code for the query;
:param edns: edns_data sent from the client side. The list with the
- EDNS options is accesible through edns.opt_list. It
+ EDNS options is accessible through edns.opt_list. It
SHOULD NOT be altered;
:param opt_list_out: the list with the EDNS options that will be sent as a
reply. It can be populated with EDNS options;
diff --git a/pythonmod/doc/modules/functions.rst b/pythonmod/doc/modules/functions.rst
index 627d44922477..49ea7bfa45f0 100644
--- a/pythonmod/doc/modules/functions.rst
+++ b/pythonmod/doc/modules/functions.rst
@@ -24,7 +24,7 @@ Cache
:param qstate: :class:`module_qstate`
:param qinfo: :class:`query_info`
:param msgrep: :class:`reply_info`
- :param is_referal: integer
+ :param is_referral: integer
:rtype: boolean
.. function:: invalidateQueryInCache(qstate, qinfo)
diff --git a/pythonmod/doc/modules/struct.rst b/pythonmod/doc/modules/struct.rst
index 3af5d8a48c01..c74298b8b75d 100644
--- a/pythonmod/doc/modules/struct.rst
+++ b/pythonmod/doc/modules/struct.rst
@@ -108,7 +108,7 @@ query_info
.. attribute:: qname_len
- Lenght of question name (number of bytes).
+ Length of question name (number of bytes).
.. attribute:: qname_list[]
diff --git a/pythonmod/doc/usecase.rst b/pythonmod/doc/usecase.rst
index 2975740bb95d..5845061b02b3 100644
--- a/pythonmod/doc/usecase.rst
+++ b/pythonmod/doc/usecase.rst
@@ -25,7 +25,7 @@ Controled by secured queries secured with private key.
Dynamic translation service
---------------------------
-DNS request can be translated to virtualy any answer, that's easy to implement in client side
+DNS request can be translated to virtually any answer, that's easy to implement in client side
because of many DNS libraries available.
Examples :
diff --git a/pythonmod/examples/edns.py b/pythonmod/examples/edns.py
index 3fae1c652af8..37ce9e27923d 100644
--- a/pythonmod/examples/edns.py
+++ b/pythonmod/examples/edns.py
@@ -77,7 +77,7 @@ def init_standard(id, env):
The function's signature is the same as the C counterpart and allows for
extra functionality during init.
..note:: This function is preferred by unbound over the old init function.
- ..note:: The previously accesible configuration options can now be found in
+ ..note:: The previously accessible configuration options can now be found in
env.cgf.
"""
log_info("python: inited script {}".format(env.cfg.python_script))
@@ -94,7 +94,7 @@ def init(id, cfg):
"""Previous version init function.
..note:: This function is still supported for backwards compatibility when
the init_standard function is missing. When init_standard is
- present this function SHOULD be ommited to avoid confusion to the
+ present this function SHOULD be omitted to avoid confusion to the
reader.
"""
return True
diff --git a/pythonmod/interface.i b/pythonmod/interface.i
index 09d726f2cf46..748dec52db41 100644
--- a/pythonmod/interface.i
+++ b/pythonmod/interface.i
@@ -1277,7 +1277,7 @@ struct delegpt* find_delegation(struct module_qstate* qstate, char *nm, size_t n
Functions
* ************************************************************************************ */
/******************************
- * Various debuging functions *
+ * Various debugging functions *
******************************/
void verbose(enum verbosity_value level, const char* format, ...);
void log_info(const char* format, ...);
diff --git a/pythonmod/examples/inplace_callbacks.py b/pythonmod/examples/inplace_callbacks.py
index 751dee510854..02ee56e36e21 100644
--- a/pythonmod/examples/inplace_callbacks.py
+++ b/pythonmod/examples/inplace_callbacks.py
@@ -99,7 +99,7 @@ def inplace_cache_callback(qinfo, qstate, rep, rcode, edns, opt_list_out,
:param rep: reply_info struct;
:param rcode: return code for the query;
:param edns: edns_data sent from the client side. The list with the EDNS
options is accesible through edns.opt_list. It SHOULD NOT be
altered;
:param opt_list_out: the list with the EDNS options that will be sent as a
reply. It can be populated with EDNS options;
@@ -107,7 +107,7 @@ def inplace_cache_callback(qinfo, qstate, rep, rcode, edns, opt_list_out,
want to append a new option to opt_list_out.
:return: True on success, False on failure.
- For demostration purposes we want to see if EDNS option 65002 is present
+ For demonstration purposes we want to see if EDNS option 65002 is present
and reply with a new value.
"""
log_info("python: called back while answering from cache.")
@@ -142,7 +142,7 @@ def inplace_local_callback(qinfo, qstate, rep, rcode, edns, opt_list_out,
:param rep: reply_info struct;
:param rcode: return code for the query;
:param edns: edns_data sent from the client side. The list with the
EDNS options is accesible through edns.opt_list. It
SHOULD NOT be altered;
:param opt_list_out: the list with the EDNS options that will be sent as a
reply. It can be populated with EDNS options;
@@ -173,7 +173,7 @@ def inplace_servfail_callback(qinfo, qstate, rep, rcode, edns, opt_list_out,
want to append a new option to opt_list_out.
:return: True on success, False on failure.
- For demostration purposes we want to reply with an empty EDNS code '65003'.
+ For demonstration purposes we want to reply with an empty EDNS code '65003'.
"""
log_info("python: called back while servfail.")
b = bytearray.fromhex("")
@@ -186,7 +186,7 @@ def init_standard(id, env):
The function's signature is the same as the C counterpart and allows for
extra functionality during init.
..note:: This function is preferred by unbound over the old init function.
- ..note:: The previously accesible configuration options can now be found in
+ ..note:: The previously accessible configuration options can now be found in
env.cgf.
"""
log_info("python: inited script {}".format(env.cfg.python_script))
@@ -218,7 +218,7 @@ def init(id, cfg):
"""Previous version init function.
..note:: This function is still supported for backwards compatibility when
the init_standard function is missing. When init_standard is
- present this function SHOULD be ommited to avoid confusion to the
+ present this function SHOULD be omitted to avoid confusion to the
reader.
"""
return True
@@ -99,7 +99,7 @@ def inplace_cache_callback(qinfo, qstate, rep, rcode, edns, opt_list_out,
:param rcode: return code for the query;
:param edns: edns_data sent from the client side. The list with the EDNS
- options is accesible through edns.opt_list. It SHOULD NOT be
+ options is accessible through edns.opt_list. It SHOULD NOT be
altered;
:param opt_list_out: the list with the EDNS options that will be sent as a
@@ -142,7 +142,7 @@ def inplace_local_callback(qinfo, qstate, rep, rcode, edns, opt_list_out,
:param rcode: return code for the query;
:param edns: edns_data sent from the client side. The list with the
- EDNS options is accesible through edns.opt_list. It
+ EDNS options is accessible through edns.opt_list. It
SHOULD NOT be altered;
:param opt_list_out: the list with the EDNS options that will be sent as a